@@ -1,4 +1,4 @@
-# Copyright 2011-2012 Yuki Izumi. ( anneli AT cpan DOT org )
+# Copyright 2011-2016 Yuki Izumi. ( anneli AT cpan DOT org )
 # This is free software; you can redistribute it and/or modify it under the
 # same terms as Perl itself.
 
@@ -38,11 +38,11 @@ Erlang::Parser - Erlang source code parser
 
 =head1 VERSION
 
-This document describes version 0.5.2 of Erlang::Parser released 2014-01-27.
+This document describes version 0.5.3 of Erlang::Parser released 2016-06-20.
 
 =cut
 
-our $VERSION = '0.5.2';
+our $VERSION = '0.5.3';
 
 =head1 SYNOPSIS
 
@@ -107,25 +107,21 @@ Other places of interest:
 
 =item * GitHub: source code repository
 
-L<http://github.com/unnali/Erlang--Parser>
+L<http://github.com/kivikakk/Erlang--Parser>
 
 =item * GitHub: open an issue
 
-L<http://github.com/unnali/Erlang--Parser/issues>
-
-=item * Mailing list
-
-L<http://groups.google.com/group/erlang--parser-devel>, <erlang--parser-devel@googlegroups.com>
+L<http://github.com/kivikakk/Erlang--Parser/issues>
 
 =item * Twitter: the author
 
-L<http://twitter.com/unnali>
+L<http://twitter.com/kivikakk>
 
 =back
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2011-2012, Yuki Izumi C<< <ANNELI@CPAN.org> >>. All rights
+Copyright (c) 2011-2016, Yuki Izumi C<< <ANNELI@CPAN.org> >>. All rights
 reserved.
 
 This module is free software; you can redistribute it and/or
